import csv
import sys
from ne_extractor import get_named_entity
from parsed_sentence import ParsedSentence
from parsed_sentence import ParsedSentenceReader


if not len(sys.argv) == 2:
	print("Usage: input_file")
	exit()

input_file_path=sys.argv[1]

# initialize the sentence reader
psr = ParsedSentenceReader(input_file_path)

#for each sentence
while True:
	ps = psr.read_next_sentence()
	#if there are no more sentences, break
	if not ps:
		break

	#get the token indexed
	indexes = ps.get_indexes();
	print(indexes)

	print("==============================================================================")

	# get the surface, lemma and pos for each token
	for index in indexes:
		surface = ps.get_surface(index);
		lemma = ps.get_lemma(index);
		pos = ps.get_postag(index);
		print("{} {} {} {}".format(index, surface, lemma, pos))

	print("==============================================================================")

	# get the named entities in the sentence
	# you can only focus on a subset of named entities
	accepted_categories=["PERSON","LOCATION"]
	found_named_entities = get_named_entity(ps, accepted_categories)

	for ne_category in found_named_entities:
		spans = found_named_entities[ne_category]
		for span in spans:
			print("{} {}".format(ne_category, span))

	print("==============================================================================")

	for index in indexes:
		children_indexes = ps.get_children_indexes(index)
		print("The children of {} are {}".format(index, children_indexes))

	for index in indexes:
		father_id = ps.get_father_id(index)
		relation = ps.get_relation(father_id, index)
		print("The father of {} is {} with the relation {}".format(index, father_id, relation))
